Events
-------

Main
^^^^^^^^^^^^^^^^
*events_create()*
"""""""""""""""""
.. autofunction:: neurokit2.events.events_create

*events_find()*
""""""""""""""""
.. autofunction:: neurokit2.events.events_find

*events_plot()*
"""""""""""""""""
.. autofunction:: neurokit2.events.events_plot

*events_to_mne()*
""""""""""""""""""""""
.. autofunction:: neurokit2.events.events_to_mne
